==> cscec5b-xell-api-3.0.1-20221129.032914-30-sources.jar: com/ejianc/business/wzxt/vo/CheckWeighVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 验收磅单表
 *
 * @author generator
 *
 */
public class CheckWeighVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long checkId; // 验收主键ID
    private Long checkDetailId; // 验收明细主键ID
    private String pkWeighBill; // 磅单主键
    private String weighCode; // 磅单编号
    private String plateNumber; // 车牌号
    private String carSerial; // 车次
    private String forwardingUnit; // 发货单位、供应商
    private String consigneeUnit; // 收货单位、收货项目
    private String materialName; // 物料名称
    private String materialSpec; // 规格型号
    private BigDecimal grossWeight; // 毛重
    private BigDecimal tareWeight; // 皮重
    private BigDecimal netWeight; // 净重
    private String weightUnit; // 重量单位
    private String grossTime; // 毛重时间
    private String tareTime; // 皮重时间
    private String thirdWeighId; // 来源称重系统称重结果ID
    private String source; // 数据来源
    private BigDecimal checkNum; // 验收数量
    private BigDecimal surplusNums; // 剩余数量  净重-验收数量


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getCheckDetailId() {
        return checkDetailId;
    }

    public void setCheckDetailId(Long checkDetailId) {
        this.checkDetailId = checkDetailId;
    }
    public String getPkWeighBill() {
        return pkWeighBill;
    }

    public void setPkWeighBill(String pkWeighBill) {
        this.pkWeighBill = pkWeighBill;
    }
    public String getWeighCode() {
        return weighCode;
    }

    public void setWeighCode(String weighCode) {
        this.weighCode = weighCode;
    }
    public String getPlateNumber() {
        return plateNumber;
    }

    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }
    public String getCarSerial() {
        return carSerial;
    }

    public void setCarSerial(String carSerial) {
        this.carSerial = carSerial;
    }
    public String getForwardingUnit() {
        return forwardingUnit;
    }

    public void setForwardingUnit(String forwardingUnit) {
        this.forwardingUnit = forwardingUnit;
    }
    public String getConsigneeUnit() {
        return consigneeUnit;
    }

    public void setConsigneeUnit(String consigneeUnit) {
        this.consigneeUnit = consigneeUnit;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public BigDecimal getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public String getWeightUnit() {
        return weightUnit;
    }

    public void setWeightUnit(String weightUnit) {
        this.weightUnit = weightUnit;
    }
    public String getGrossTime() {
        return grossTime;
    }

    public void setGrossTime(String grossTime) {
        this.grossTime = grossTime;
    }
    public String getTareTime() {
        return tareTime;
    }

    public void setTareTime(String tareTime) {
        this.tareTime = tareTime;
    }
    public String getThirdWeighId() {
        return thirdWeighId;
    }

    public void setThirdWeighId(String thirdWeighId) {
        this.thirdWeighId = thirdWeighId;
    }
    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public BigDecimal getSurplusNums() {
        return surplusNums;
    }

    public void setSurplusNums(BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }

}

==> cscec5b-xell-api-3.0.1-20230302.080134-58-sources.jar: com/ejianc/business/wzxt/vo/CheckWeighVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 验收磅单表
 *
 * @author generator
 *
 */
public class CheckWeighVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long checkId; // 验收主键ID
    private Long checkDetailId; // 验收明细主键ID
    private String pkWeighBill; // 磅单主键
    private String weighCode; // 磅单编号
    private String plateNumber; // 车牌号
    private String carSerial; // 车次
    private String forwardingUnit; // 发货单位、供应商
    private String consigneeUnit; // 收货单位、收货项目
    private String materialName; // 物料名称
    private String materialSpec; // 规格型号
    private BigDecimal grossWeight; // 毛重
    private BigDecimal tareWeight; // 皮重
    private BigDecimal netWeight; // 净重
    private String weightUnit; // 重量单位
    private String grossTime; // 毛重时间
    private String tareTime; // 皮重时间
    private String thirdWeighId; // 来源称重系统称重结果ID
    private String source; // 数据来源
    private BigDecimal checkNum; // 验收数量
    private BigDecimal surplusNums; // 剩余数量  净重-验收数量
    private String weighStationCode;//磅站编号
    private String construction;//施工部位


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getCheckDetailId() {
        return checkDetailId;
    }

    public void setCheckDetailId(Long checkDetailId) {
        this.checkDetailId = checkDetailId;
    }
    public String getPkWeighBill() {
        return pkWeighBill;
    }

    public void setPkWeighBill(String pkWeighBill) {
        this.pkWeighBill = pkWeighBill;
    }
    public String getWeighCode() {
        return weighCode;
    }

    public void setWeighCode(String weighCode) {
        this.weighCode = weighCode;
    }
    public String getPlateNumber() {
        return plateNumber;
    }

    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }
    public String getCarSerial() {
        return carSerial;
    }

    public void setCarSerial(String carSerial) {
        this.carSerial = carSerial;
    }
    public String getForwardingUnit() {
        return forwardingUnit;
    }

    public void setForwardingUnit(String forwardingUnit) {
        this.forwardingUnit = forwardingUnit;
    }
    public String getConsigneeUnit() {
        return consigneeUnit;
    }

    public void setConsigneeUnit(String consigneeUnit) {
        this.consigneeUnit = consigneeUnit;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public BigDecimal getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public String getWeightUnit() {
        return weightUnit;
    }

    public void setWeightUnit(String weightUnit) {
        this.weightUnit = weightUnit;
    }
    public String getGrossTime() {
        return grossTime;
    }

    public void setGrossTime(String grossTime) {
        this.grossTime = grossTime;
    }
    public String getTareTime() {
        return tareTime;
    }

    public void setTareTime(String tareTime) {
        this.tareTime = tareTime;
    }
    public String getThirdWeighId() {
        return thirdWeighId;
    }

    public void setThirdWeighId(String thirdWeighId) {
        this.thirdWeighId = thirdWeighId;
    }
    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public BigDecimal getSurplusNums() {
        return surplusNums;
    }

    public void setSurplusNums(BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }

    public String getWeighStationCode() {
        return weighStationCode;
    }

    public void setWeighStationCode(String weighStationCode) {
        this.weighStationCode = weighStationCode;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }
}
